# eric7.WebBrowser.Sync.SyncDataPage

Module implementing the synchronization data wizard page.

### Global Attributes

None

### Classes

SyncDataPage | Class implementing the synchronization data wizard page.

### Functions

None

## SyncDataPage

Class implementing the synchronization data wizard page.

### Derived from

QWizardPage, Ui_SyncDataPage

### Class Attributes

None

### Class Methods

None

### Methods

SyncDataPage | Constructor
nextId | Public method returning the ID of the next wizard page.

### Static Methods

None

#### SyncDataPage (Constructor)

SyncDataPage(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### SyncDataPage.nextId

nextId()

Public method returning the ID of the next wizard page.

Return:
  next wizard page ID

Return Type:
  int

Up